@@ -23,11 +23,10 @@ ml_gbt_regressor_impl <- function(x, formula = NULL, max_iter = 20, max_depth =
                                      uid = random_string("gbt_regressor_"),
                                      response = NULL, features = NULL, ...) {
 
-  feature_subset_strategy <- param_min_version(x, feature_subset_strategy, "2.3.0")
+  feature_subset_strategy <- param_min_version(x, feature_subset_strategy, "2.3.0", "auto")
 
   ml_process_model(
     x = x,
-    spark_class = "org.apache.spark.ml.regression.GBTRegressor",
     r_class = "ml_gbt_regressor",
     ml_function = new_ml_model_gbt_regression,
     features = features,
@@ -35,22 +34,22 @@ ml_gbt_regressor_impl <- function(x, formula = NULL, max_iter = 20, max_depth =
     uid = uid,
     formula = formula,
     invoke_steps = list(
-      setFeaturesCol = features_col,
-      setLabelCol = label_col,
-      setPredictionCol = prediction_col,
-      setMaxIter = cast_scalar_integer(max_iter),
-      setStepSize = cast_scalar_double(step_size),
-      setSubsamplingRate = cast_scalar_double(subsampling_rate),
-      setFeatureSubsetStrategy = cast_nullable_string(feature_subset_strategy),
-      setLossType = cast_choice(loss_type, c("squared", "absolute")),
-      setCheckpointInterval = cast_scalar_integer(checkpoint_interval),
-      setMaxBins = cast_scalar_integer(max_bins),
-      setMaxDepth = cast_scalar_integer(max_depth),
-      setMinInfoGain = cast_scalar_double(min_info_gain),
-      setMinInstancesPerNode = cast_scalar_integer(min_instances_per_node),
-      setCacheNodeIds = cast_scalar_logical(cache_node_ids),
-      setMaxMemoryInMB = cast_scalar_integer(max_memory_in_mb),
-      setSeed = cast_nullable_scalar_integer(seed)
+      features_col = features_col,
+      label_col = label_col,
+      prediction_col = prediction_col,
+      max_iter = max_iter,
+      step_size = step_size,
+      subsampling_rate = subsampling_rate,
+      feature_subset_strategy = feature_subset_strategy,
+      loss_type = loss_type,
+      checkpoint_interval = checkpoint_interval,
+      max_bins = max_bins,
+      max_depth = max_depth,
+      min_info_gain = min_info_gain,
+      min_instances_per_node = min_instances_per_node,
+      cache_node_ids = cache_node_ids,
+      max_memory_in_mb = max_memory_in_mb,
+      seed = seed
     )
   )
 }
