@@ -8,7 +8,7 @@ set_option_default <- function(...) {
 }
 
 .onLoad <- function(...) {
-  if (!dbplyr_uses_ops()) {
+  if (packageVersion("dbplyr") > package_version("2.1.1")) {
     vctrs::s3_register("dbplyr::simulate_vars", "tbl_spark")
     vctrs::s3_register("dbplyr::simulate_vars_is_typed", "tbl_spark")
   }
